==> mcu_plus_sdk_am261x_11_00_00_29_docs_only.tar.xz: mcu_plus_sdk_am261x_11_00_00_29_docs_only/docs/api_guide_am261x/group__DRV__OSPI__MODULE.js <==
var group__DRV__OSPI__MODULE =
[
    [ "Generic NOR Flash API for single pin mode", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html", "group__DRV__OSPI__NOR__FLASH__API__MODULE" ],
    [ "ospi/v0/ospi.h", "ospi_2v0_2ospi_8h.html", null ],
    [ "OSPI_Attrs", "structOSPI__Attrs.html", [
      [ "baseAddr", "structOSPI__Attrs.html#a712bae2c500bef1f5d04c6a15b4457ee", null ],
      [ "dataBaseAddr", "structOSPI__Attrs.html#a2758e32ddbddeb1e3127f545aecfbcbc", null ],
      [ "inputClkFreq", "structOSPI__Attrs.html#a899a378953a89c69645e3598f40da22c", null ],
      [ "protocol", "structOSPI__Attrs.html#a3b510ab68c9354ac6c26290bb2adb9ab", null ],
      [ "intrNum", "structOSPI__Attrs.html#a8c02ae12116e6db9e5baceec960c7530", null ],
      [ "intrEnable", "structOSPI__Attrs.html#a03d4b7a0e5ec7ff904f365283b9e748e", null ],
      [ "intrPriority", "structOSPI__Attrs.html#a9b98105b59461cc25feea7ce38dab7df", null ],
      [ "dmaEnable", "structOSPI__Attrs.html#a099339f06c695c8e9bc62b88c5489b35", null ],
      [ "phyEnable", "structOSPI__Attrs.html#a940fd1e5fee67d52ecf27643d2655a81", null ],
      [ "dacEnable", "structOSPI__Attrs.html#a4652a8026110503b11eed62485c0a887", null ],
      [ "frmFmt", "structOSPI__Attrs.html#a7597d6f446c7e153587684f56209d96a", null ],
      [ "devDelays", "structOSPI__Attrs.html#a3d6fd839b2531bcb6c34aef45a39ae9d", null ],
      [ "chipSelect", "structOSPI__Attrs.html#a7f9216b376b14b8d954126b6011b5e67", null ],
      [ "decChipSelect", "structOSPI__Attrs.html#a6663207c76e3abe9f8013d9cd26859f2", null ],
      [ "baudRateDiv", "structOSPI__Attrs.html#ae957c3b4d924a730b7006f920b904060", null ],
      [ "dmaRestrictedRegions", "structOSPI__Attrs.html#a2335c7d39e1e96078e2e6392b07b4b1d", null ],
      [ "phyConfiguration", "structOSPI__Attrs.html#a65a17ba9b21d45bb1c1fe71da8050094", null ]
    ] ],
    [ "OSPI_Object", "structOSPI__Object.html", [
      [ "handle", "structOSPI__Object.html#a47550c4f636ed8ef183fda4dba8fa0eb", null ],
      [ "isOpen", "structOSPI__Object.html#a82e05007313008385b49d4bac5764cb2", null ],
      [ "isDacEnable", "structOSPI__Object.html#ab5280cabe269f6f416351280e9abb737", null ],
      [ "lockObj", "structOSPI__Object.html#ac59e394de833441bb1e9d28db10d6e5b", null ],
      [ "transferSemObj", "structOSPI__Object.html#a4fdf482885a4292639c9f81ddf4704e1", null ],
      [ "hwiObj", "structOSPI__Object.html#a7dfdf17f1f5b6a58c235095c4ed0e52a", null ],
      [ "currTrans", "structOSPI__Object.html#a7a929cbe21ad3e4bdd30f941ec124ae2", null ],
      [ "ospiDmaHandle", "structOSPI__Object.html#a79aff6bb896caaa89513af0ae842f2a7", null ],
      [ "ospilldInitObject", "structOSPI__Object.html#ac422baae08c34e6d29a1c7dac65e361f", null ],
      [ "ospilldObject", "structOSPI__Object.html#a7ffd84e250d999c6399bf5c940decd8c", null ],
      [ "ospilldHandle", "structOSPI__Object.html#ab30339bd65b27917054cadc16772e139", null ]
    ] ],
    [ "OSPI_Config", "structOSPI__Config.html", [
      [ "attrs", "structOSPI__Config.html#afae849ff69bd1a26ef1f9d574316497c", null ],
      [ "object", "structOSPI__Config.html#a23a4360ecf2230ba18ff20956ce14274", null ]
    ] ],
    [ "OSPI_Handle", "group__DRV__OSPI__MODULE.html#gaf94e42c41b084bb2f3c9cc4409213188", null ],
    [ "OSPI_init", "group__DRV__OSPI__MODULE.html#ga53c8b806a48ecdb9d3b8d17c36271819", null ],
    [ "OSPI_deinit", "group__DRV__OSPI__MODULE.html#ga4bf4c5e9986edf6545527bc9690c5f66", null ],
    [ "OSPI_Params_init", "group__DRV__OSPI__MODULE.html#ga2a6c4001017c758a627f1cd78115e120", null ],
    [ "OSPI_open", "group__DRV__OSPI__MODULE.html#gaf74c4b8836a43513f0b2c0a7893c02da", null ],
    [ "OSPI_close", "group__DRV__OSPI__MODULE.html#ga6be5558d3c8085469468d6f8e7c697f2", null ],
    [ "OSPI_getHandle", "group__DRV__OSPI__MODULE.html#gac9779c195e27fabcc62aaa1045e9b05f", null ],
    [ "OSPI_readDirect", "group__DRV__OSPI__MODULE.html#gadf95ceab8b2d8466b6dbc94bb3ab0a56", null ],
    [ "OSPI_readIndirect", "group__DRV__OSPI__MODULE.html#ga8f67a450022d20e50cc726084b0f36af", null ],
    [ "OSPI_writeDirect", "group__DRV__OSPI__MODULE.html#gab7a73f169d42c9aa17ac75f40af3db4d", null ],
    [ "OSPI_writeIndirect", "group__DRV__OSPI__MODULE.html#ga32d6168dcfa566f8fc11f6e2f76f71e6", null ],
    [ "OSPI_readCmd", "group__DRV__OSPI__MODULE.html#ga068459dfaa30ff756183498515daa7ac", null ],
    [ "OSPI_writeCmd", "group__DRV__OSPI__MODULE.html#ga0decd6fd76069512d26890d90fc12e78", null ],
    [ "OSPI_Transaction_init", "group__DRV__OSPI__MODULE.html#ga66014cbd24d8c287c94846a049d9da68", null ],
    [ "OSPI_ReadCmdParams_init", "group__DRV__OSPI__MODULE.html#gac0fea092fe6e546dd99afbac73aa1cb5", null ],
    [ "OSPI_WriteCmdParams_init", "group__DRV__OSPI__MODULE.html#ga7e7fe11788a7985ea5075fa1f628b437", null ],
    [ "OSPI_getInputClk", "group__DRV__OSPI__MODULE.html#gac2f47121c92b9d033b0b1c7540d0c8d7", null ],
    [ "OSPI_isDacEnable", "group__DRV__OSPI__MODULE.html#gacfdbd06fc0504e3a3eed1c31a2d42fd3", null ],
    [ "OSPI_isDmaEnable", "group__DRV__OSPI__MODULE.html#gaee5fdd9553f4bd0223b85abf6261d15f", null ],
    [ "OSPI_isIntrEnable", "group__DRV__OSPI__MODULE.html#ga77f5a9e01741701f6330bdedf85b7321", null ],
    [ "OSPI_isPhyEnable", "group__DRV__OSPI__MODULE.html#ga3be4b0de1b7d5267d614cbec80e86c37", null ],
    [ "OSPI_isDtrEnable", "group__DRV__OSPI__MODULE.html#ga353a685bc155f7ae996f558f3b529317", null ],
    [ "OSPI_enableDDR", "group__DRV__OSPI__MODULE.html#ga0de448ce4c70f2ee98af6707356bcbe5", null ],
    [ "OSPI_enableSDR", "group__DRV__OSPI__MODULE.html#ga71774ed21246ab68c4e27f01c466c809", null ],
    [ "OSPI_enableDdrRdCmds", "group__DRV__OSPI__MODULE.html#ga0137399fd2f537445956e40ec0ae7257", null ],
    [ "OSPI_setRdDataCaptureDelay", "group__DRV__OSPI__MODULE.html#ga9421b052a58bf3cbe326b5d74919a877", null ],
    [ "OSPI_setNumAddrBytes", "group__DRV__OSPI__MODULE.html#ga89e702ca1f019b5d88fa8bb2c030ab38", null ],
    [ "OSPI_setDeviceSize", "group__DRV__OSPI__MODULE.html#ga4c8d90f7305e72b77489e2fda76565cd", null ],
    [ "OSPI_setCmdDummyCycles", "group__DRV__OSPI__MODULE.html#gab738b402ed88d112d1414dc33b22ab85", null ],
    [ "OSPI_setReadDummyCycles", "group__DRV__OSPI__MODULE.html#ga68a204e2a560c924a71c03d4b372f5ad", null ],
    [ "OSPI_setWriteDummyCycles", "group__DRV__OSPI__MODULE.html#ga6d161467cb4487ab3fc3462558578f01", null ],
    [ "OSPI_setPhyEnableSuccess", "group__DRV__OSPI__MODULE.html#ga99056e6c013a944620dd45cc6d69a80b", null ],
    [ "OSPI_setModeBits", "group__DRV__OSPI__MODULE.html#ga4c718fa1c185434d2e84146005883447", null ],
    [ "OSPI_enableModeBitsCmd", "group__DRV__OSPI__MODULE.html#ga9f8a3ee5c33cf3ca9e02319456d71330", null ],
    [ "OSPI_enableModeBitsRead", "group__DRV__OSPI__MODULE.html#gaafe5e8aa4ae563bd4c067dfca4b68d44", null ],
    [ "OSPI_getPhyEnableSuccess", "group__DRV__OSPI__MODULE.html#gab9fa291138465098c9e98ac074849e4c", null ],
    [ "OSPI_cmdModeBitSet", "group__DRV__OSPI__MODULE.html#ga1fd1161bd5604bf6f1d407939482c955", null ],
    [ "OSPI_rdModeBitSet", "group__DRV__OSPI__MODULE.html#ga2f6f3296f315d5c519cb23757dbb26e8", null ],
    [ "OSPI_getProtocol", "group__DRV__OSPI__MODULE.html#ga6f1745f40bd55489e6b664ffeebf5273", null ],
    [ "OSPI_setProtocol", "group__DRV__OSPI__MODULE.html#ga389adec0e7fc0966af6a47c514826c52", null ],
    [ "OSPI_setDualOpCodeMode", "group__DRV__OSPI__MODULE.html#gac799c521f13c9ba7d42d46a9e8425e1e", null ],
    [ "OSPI_clearDualOpCodeMode", "group__DRV__OSPI__MODULE.html#gabbc54d5d48c72e6f1ab0ede20c8a77fb", null ],
    [ "OSPI_setXferOpCodes", "group__DRV__OSPI__MODULE.html#gac04d05439c8e99fc638e397abdfd801b", null ],
    [ "OSPI_setCmdExtType", "group__DRV__OSPI__MODULE.html#ga50c51cccae6641360d76408715e713f0", null ],
    [ "OSPI_enableDacMode", "group__DRV__OSPI__MODULE.html#ga038e066fc28090e138363c859b027869", null ],
    [ "OSPI_disableDacMode", "group__DRV__OSPI__MODULE.html#ga55d02050f79b0efdc5dcddcdbc94bfd8", null ],
    [ "OSPI_getFlashDataBaseAddr", "group__DRV__OSPI__MODULE.html#gac85aad283f153e3c2a4a717660ef92d8", null ],
    [ "OSPI_phyTuneDDR", "group__DRV__OSPI__MODULE.html#gafd38c99387c090ae11f944bfdae39354", null ],
    [ "OSPI_phyTuneSDR", "group__DRV__OSPI__MODULE.html#gaf17f99e5fa0d563a7be5871601e4cf25", null ],
    [ "OSPI_phyTuneGrapher", "group__DRV__OSPI__MODULE.html#gaa6badda57c28836a5d19871e6c286a52", null ],
    [ "OSPI_phyGetTuningData", "group__DRV__OSPI__MODULE.html#gac30f489140d0ff25405969f349a754f4", null ],
    [ "OSPI_phyReadAttackVector", "group__DRV__OSPI__MODULE.html#ga3af2d81bc9e28cb9b7ca4835ff7c1716", null ],
    [ "OSPI_enablePhy", "group__DRV__OSPI__MODULE.html#gac1e3e646e56fade0dae155b15145ed09", null ],
    [ "OSPI_disablePhy", "group__DRV__OSPI__MODULE.html#ga6da77149b2e1ccb884117269bb8da65d", null ],
    [ "OSPI_enablePhyPipeline", "group__DRV__OSPI__MODULE.html#ga28a185b5eeed7a8dd56f35b116a44695", null ],
    [ "OSPI_disablePhyPipeline", "group__DRV__OSPI__MODULE.html#ga6d9b5b1d5eeedfe5fb06d2e38d096c8f", null ],
    [ "gOspiConfig", "group__DRV__OSPI__MODULE.html#ga9dd730ce6cdd6b12a70d504c407d83ac", null ],
    [ "gOspiConfigNum", "group__DRV__OSPI__MODULE.html#gad2886a408f41de0874d6cedf9696f363", null ],
    [ "gOspiDmaConfig", "group__DRV__OSPI__MODULE.html#ga25a1cfdd389ac19b88e92bfe8d788d6f", null ]
];

==> mcu_plus_sdk_am261x_11_01_00_19_docs_only.tar.xz: mcu_plus_sdk_am261x_11_01_00_19_docs_only/docs/api_guide_am261x/group__DRV__OSPI__MODULE.js <==
var group__DRV__OSPI__MODULE =
[
    [ "Generic NOR Flash API for single pin mode", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html", "group__DRV__OSPI__NOR__FLASH__API__MODULE" ],
    [ "ospi/v0/ospi.h", "ospi_2v0_2ospi_8h.html", null ],
    [ "OSPI_Attrs", "structOSPI__Attrs.html", [
      [ "baseAddr", "structOSPI__Attrs.html#a712bae2c500bef1f5d04c6a15b4457ee", null ],
      [ "dataBaseAddr", "structOSPI__Attrs.html#a2758e32ddbddeb1e3127f545aecfbcbc", null ],
      [ "moduleId", "structOSPI__Attrs.html#a24bdc7cf61b005ceeb002b689bcb26d5", null ],
      [ "clkId", "structOSPI__Attrs.html#a3a3160e9cf4411544760f39970bb42eb", null ],
      [ "inputClkFreq", "structOSPI__Attrs.html#a899a378953a89c69645e3598f40da22c", null ],
      [ "protocol", "structOSPI__Attrs.html#a3b510ab68c9354ac6c26290bb2adb9ab", null ],
      [ "intrNum", "structOSPI__Attrs.html#a8c02ae12116e6db9e5baceec960c7530", null ],
      [ "intrEnable", "structOSPI__Attrs.html#a03d4b7a0e5ec7ff904f365283b9e748e", null ],
      [ "intrPriority", "structOSPI__Attrs.html#a9b98105b59461cc25feea7ce38dab7df", null ],
      [ "dmaEnable", "structOSPI__Attrs.html#a099339f06c695c8e9bc62b88c5489b35", null ],
      [ "phyEnable", "structOSPI__Attrs.html#a940fd1e5fee67d52ecf27643d2655a81", null ],
      [ "dacEnable", "structOSPI__Attrs.html#a4652a8026110503b11eed62485c0a887", null ],
      [ "frmFmt", "structOSPI__Attrs.html#a7597d6f446c7e153587684f56209d96a", null ],
      [ "devDelays", "structOSPI__Attrs.html#a3d6fd839b2531bcb6c34aef45a39ae9d", null ],
      [ "chipSelect", "structOSPI__Attrs.html#a7f9216b376b14b8d954126b6011b5e67", null ],
      [ "decChipSelect", "structOSPI__Attrs.html#a6663207c76e3abe9f8013d9cd26859f2", null ],
      [ "baudRateDiv", "structOSPI__Attrs.html#ae957c3b4d924a730b7006f920b904060", null ],
      [ "validateOtp", "structOSPI__Attrs.html#af85d19d34e88ea54cda7fecd8e00717c", null ],
      [ "dmaRestrictedRegions", "structOSPI__Attrs.html#a2335c7d39e1e96078e2e6392b07b4b1d", null ],
      [ "phyConfiguration", "structOSPI__Attrs.html#a65a17ba9b21d45bb1c1fe71da8050094", null ]
    ] ],
    [ "OSPI_Object", "structOSPI__Object.html", [
      [ "handle", "structOSPI__Object.html#a47550c4f636ed8ef183fda4dba8fa0eb", null ],
      [ "isOpen", "structOSPI__Object.html#a82e05007313008385b49d4bac5764cb2", null ],
      [ "isDacEnable", "structOSPI__Object.html#ab5280cabe269f6f416351280e9abb737", null ],
      [ "lockObj", "structOSPI__Object.html#ac59e394de833441bb1e9d28db10d6e5b", null ],
      [ "transferSemObj", "structOSPI__Object.html#a4fdf482885a4292639c9f81ddf4704e1", null ],
      [ "hwiObj", "structOSPI__Object.html#a7dfdf17f1f5b6a58c235095c4ed0e52a", null ],
      [ "currTrans", "structOSPI__Object.html#a7a929cbe21ad3e4bdd30f941ec124ae2", null ],
      [ "ospiDmaHandle", "structOSPI__Object.html#a79aff6bb896caaa89513af0ae842f2a7", null ],
      [ "ospilldInitObject", "structOSPI__Object.html#ac422baae08c34e6d29a1c7dac65e361f", null ],
      [ "ospilldObject", "structOSPI__Object.html#a7ffd84e250d999c6399bf5c940decd8c", null ],
      [ "ospilldHandle", "structOSPI__Object.html#ab30339bd65b27917054cadc16772e139", null ]
    ] ],
    [ "OSPI_Config", "structOSPI__Config.html", [
      [ "attrs", "structOSPI__Config.html#afae849ff69bd1a26ef1f9d574316497c", null ],
      [ "object", "structOSPI__Config.html#a23a4360ecf2230ba18ff20956ce14274", null ]
    ] ],
    [ "OSPI_Handle", "group__DRV__OSPI__MODULE.html#ga8c2031191786535e341c5366de1e4a61", null ],
    [ "OSPI_init", "group__DRV__OSPI__MODULE.html#ga53c8b806a48ecdb9d3b8d17c36271819", null ],
    [ "OSPI_deinit", "group__DRV__OSPI__MODULE.html#ga4bf4c5e9986edf6545527bc9690c5f66", null ],
    [ "OSPI_Params_init", "group__DRV__OSPI__MODULE.html#ga2a6c4001017c758a627f1cd78115e120", null ],
    [ "OSPI_open", "group__DRV__OSPI__MODULE.html#gaf74c4b8836a43513f0b2c0a7893c02da", null ],
    [ "OSPI_close", "group__DRV__OSPI__MODULE.html#ga6be5558d3c8085469468d6f8e7c697f2", null ],
    [ "OSPI_getHandle", "group__DRV__OSPI__MODULE.html#gac9779c195e27fabcc62aaa1045e9b05f", null ],
    [ "OSPI_readDirect", "group__DRV__OSPI__MODULE.html#gadf95ceab8b2d8466b6dbc94bb3ab0a56", null ],
    [ "OSPI_readIndirect", "group__DRV__OSPI__MODULE.html#ga8f67a450022d20e50cc726084b0f36af", null ],
    [ "OSPI_writeDirect", "group__DRV__OSPI__MODULE.html#gab7a73f169d42c9aa17ac75f40af3db4d", null ],
    [ "OSPI_writeIndirect", "group__DRV__OSPI__MODULE.html#ga32d6168dcfa566f8fc11f6e2f76f71e6", null ],
    [ "OSPI_readCmd", "group__DRV__OSPI__MODULE.html#ga068459dfaa30ff756183498515daa7ac", null ],
    [ "OSPI_writeCmd", "group__DRV__OSPI__MODULE.html#ga0decd6fd76069512d26890d90fc12e78", null ],
    [ "OSPI_Transaction_init", "group__DRV__OSPI__MODULE.html#ga66014cbd24d8c287c94846a049d9da68", null ],
    [ "OSPI_ReadCmdParams_init", "group__DRV__OSPI__MODULE.html#gac0fea092fe6e546dd99afbac73aa1cb5", null ],
    [ "OSPI_WriteCmdParams_init", "group__DRV__OSPI__MODULE.html#ga7e7fe11788a7985ea5075fa1f628b437", null ],
    [ "OSPI_getInputClk", "group__DRV__OSPI__MODULE.html#gac2f47121c92b9d033b0b1c7540d0c8d7", null ],
    [ "OSPI_isDacEnable", "group__DRV__OSPI__MODULE.html#gacfdbd06fc0504e3a3eed1c31a2d42fd3", null ],
    [ "OSPI_isDmaEnable", "group__DRV__OSPI__MODULE.html#gaee5fdd9553f4bd0223b85abf6261d15f", null ],
    [ "OSPI_isIntrEnable", "group__DRV__OSPI__MODULE.html#ga77f5a9e01741701f6330bdedf85b7321", null ],
    [ "OSPI_isPhyEnable", "group__DRV__OSPI__MODULE.html#ga3be4b0de1b7d5267d614cbec80e86c37", null ],
    [ "OSPI_isDtrEnable", "group__DRV__OSPI__MODULE.html#ga353a685bc155f7ae996f558f3b529317", null ],
    [ "OSPI_enableDDR", "group__DRV__OSPI__MODULE.html#ga0de448ce4c70f2ee98af6707356bcbe5", null ],
    [ "OSPI_enableSDR", "group__DRV__OSPI__MODULE.html#ga71774ed21246ab68c4e27f01c466c809", null ],
    [ "OSPI_enableDdrRdCmds", "group__DRV__OSPI__MODULE.html#ga0137399fd2f537445956e40ec0ae7257", null ],
    [ "OSPI_setRdDataCaptureDelay", "group__DRV__OSPI__MODULE.html#ga9421b052a58bf3cbe326b5d74919a877", null ],
    [ "OSPI_setNumAddrBytes", "group__DRV__OSPI__MODULE.html#ga89e702ca1f019b5d88fa8bb2c030ab38", null ],
    [ "OSPI_setDeviceSize", "group__DRV__OSPI__MODULE.html#ga4c8d90f7305e72b77489e2fda76565cd", null ],
    [ "OSPI_setCmdDummyCycles", "group__DRV__OSPI__MODULE.html#gab738b402ed88d112d1414dc33b22ab85", null ],
    [ "OSPI_setReadDummyCycles", "group__DRV__OSPI__MODULE.html#ga68a204e2a560c924a71c03d4b372f5ad", null ],
    [ "OSPI_setWriteDummyCycles", "group__DRV__OSPI__MODULE.html#ga6d161467cb4487ab3fc3462558578f01", null ],
    [ "OSPI_setPhyEnableSuccess", "group__DRV__OSPI__MODULE.html#ga99056e6c013a944620dd45cc6d69a80b", null ],
    [ "OSPI_setModeBits", "group__DRV__OSPI__MODULE.html#ga4c718fa1c185434d2e84146005883447", null ],
    [ "OSPI_enableModeBitsCmd", "group__DRV__OSPI__MODULE.html#ga9f8a3ee5c33cf3ca9e02319456d71330", null ],
    [ "OSPI_enableModeBitsRead", "group__DRV__OSPI__MODULE.html#gaafe5e8aa4ae563bd4c067dfca4b68d44", null ],
    [ "OSPI_getPhyEnableSuccess", "group__DRV__OSPI__MODULE.html#gab9fa291138465098c9e98ac074849e4c", null ],
    [ "OSPI_cmdModeBitSet", "group__DRV__OSPI__MODULE.html#ga1fd1161bd5604bf6f1d407939482c955", null ],
    [ "OSPI_rdModeBitSet", "group__DRV__OSPI__MODULE.html#ga2f6f3296f315d5c519cb23757dbb26e8", null ],
    [ "OSPI_getProtocol", "group__DRV__OSPI__MODULE.html#ga6f1745f40bd55489e6b664ffeebf5273", null ],
    [ "OSPI_setProtocol", "group__DRV__OSPI__MODULE.html#ga389adec0e7fc0966af6a47c514826c52", null ],
    [ "OSPI_setDualOpCodeMode", "group__DRV__OSPI__MODULE.html#gac799c521f13c9ba7d42d46a9e8425e1e", null ],
    [ "OSPI_clearDualOpCodeMode", "group__DRV__OSPI__MODULE.html#gabbc54d5d48c72e6f1ab0ede20c8a77fb", null ],
    [ "OSPI_setXferOpCodes", "group__DRV__OSPI__MODULE.html#gac04d05439c8e99fc638e397abdfd801b", null ],
    [ "OSPI_setCmdExtType", "group__DRV__OSPI__MODULE.html#ga50c51cccae6641360d76408715e713f0", null ],
    [ "OSPI_enableDacMode", "group__DRV__OSPI__MODULE.html#ga038e066fc28090e138363c859b027869", null ],
    [ "OSPI_disableDacMode", "group__DRV__OSPI__MODULE.html#ga55d02050f79b0efdc5dcddcdbc94bfd8", null ],
    [ "OSPI_getFlashDataBaseAddr", "group__DRV__OSPI__MODULE.html#gac85aad283f153e3c2a4a717660ef92d8", null ],
    [ "OSPI_phyTuneDDR", "group__DRV__OSPI__MODULE.html#gafd38c99387c090ae11f944bfdae39354", null ],
    [ "OSPI_phyTuneSDR", "group__DRV__OSPI__MODULE.html#gaf17f99e5fa0d563a7be5871601e4cf25", null ],
    [ "OSPI_phyTuneGrapher", "group__DRV__OSPI__MODULE.html#gaa6badda57c28836a5d19871e6c286a52", null ],
    [ "OSPI_phyGetTuningData", "group__DRV__OSPI__MODULE.html#gac30f489140d0ff25405969f349a754f4", null ],
    [ "OSPI_phyReadAttackVector", "group__DRV__OSPI__MODULE.html#ga3af2d81bc9e28cb9b7ca4835ff7c1716", null ],
    [ "OSPI_enablePhy", "group__DRV__OSPI__MODULE.html#gac1e3e646e56fade0dae155b15145ed09", null ],
    [ "OSPI_disablePhy", "group__DRV__OSPI__MODULE.html#ga6da77149b2e1ccb884117269bb8da65d", null ],
    [ "OSPI_enablePhyPipeline", "group__DRV__OSPI__MODULE.html#ga28a185b5eeed7a8dd56f35b116a44695", null ],
    [ "OSPI_disablePhyPipeline", "group__DRV__OSPI__MODULE.html#ga6d9b5b1d5eeedfe5fb06d2e38d096c8f", null ],
    [ "gOspiConfig", "group__DRV__OSPI__MODULE.html#ga9dd730ce6cdd6b12a70d504c407d83ac", null ],
    [ "gOspiConfigNum", "group__DRV__OSPI__MODULE.html#gad2886a408f41de0874d6cedf9696f363", null ],
    [ "gOspiDmaConfig", "group__DRV__OSPI__MODULE.html#ga25a1cfdd389ac19b88e92bfe8d788d6f", null ]
];
